
#include "..\config.h"
#include "string.h"
#include "userDataProcess.h"

// Delay ms
// input: 0~65535 
void delayUs(INT16U us) {
    INT16U i=0;
	INT16U j=0;
    for(i=0; i<=us; i++) {
	    for(j=0; j<=16; j++);
	}
}

// Delay us
// input: 0~65535 
void delayMs(INT16U ms) {
    INT16U i=0;
    for(i=0; i<=ms; i++) {
	    delayUs(1000);
	}
}

// Initialize Key1 ~ Key4 PIN as input
void keyInit(void) {
    FIO2DIR &= ~KEY1;        // Set P2.10(KEY1) as input
	FIO2DIR &= ~KEY2;        // Set P2.11(KEY2) as input
    FIO2DIR &= ~KEY3;        // Set P2.12(KEY3) as input
    FIO2DIR &= ~KEY4;        // Set P2.13(KEY4) as input
}

// Set DB7~DB0 PIN as input or ourput
// direction=1 -> input   direction=0(or any other value non-1) -> output;   
void lcdDdataPinsDirectionSet(INT8U direction) {
    if(direction==1) {
		FIO0DIR2 = 0x00;      // Set P0.23~P0.16 as input
	}
	else {
		FIO0DIR2 = 0xFF;      // Set P0.23~P0.16 as output
	}
}

// Initialize LCD control PINs as output; RST, CD, RW, E;
void lcdPinInit(void) {
    FIO0DIR |= RST;                 // set P0.15(RST) as output
	FIO1DIR |= CD;                  // set P1.31(A0) as output
	FIO3DIR |= RW;                  // set P3.25(RW) as output
	FIO3DIR |= E;                   // set P3.26(E) as output

	lcdDdataPinsDirectionSet(0);    // set data pins as output
}

// Set RST level
// Input:   0->Low;  1->High
void setRST(INT8U RST_value) {
	if(RST_value == 0) {
		FIO0CLR = RST;	     // RST = 0
	}
	else {
		FIO0SET = RST;		 // RST = 1
	}
}  

// Set CD level
// Input:   0->Low;  1->High
void setCD(INT8U CD_value) {
	if(CD_value == 0) {
		FIO1CLR = CD;	     // CD = 0
	}
	else {
		FIO1SET = CD;		 // CD = 1
	}
}

// Set RW level
// Input:   0->Low;  1->High
void setRW(INT8U RW_value) {
	if(RW_value == 0) {
		FIO3CLR = RW;	     // RW = 0
	}
	else {
		FIO3SET = RW;		 // RW = 1
   }
}

// Set E level
// Input:   0->Low;  1->High
void setE(INT8U E_value) {
	if(E_value == 0) {
		FIO3CLR = E;	     // E = 0
	}
	else {
		FIO3SET = E;		 // E = 1
    }
}



// Write command
// Input:  Refer to Command Set	of Data Sheet
void writeComd(INT8U comd) {

    //lcdDdataPinsDirectionSet(0);	      // DB7~DB0 as output
	
	setRW(0);  setCD(0);				  // Write instruction register

	FIO0PIN2 = comd;  // output command on P0.23~P0.16, as a 8bits bus
    
	FIO3SET = E; // E = 1	(faster)
	FIO3CLR = E; // E = 0	(faster)
	delayUs(2);
}



// Wirte data,
// Input:  Refer to Data Sheet
void writeData(INT8U data) {
	
	//lcdDdataPinsDirectionSet(0);	      // DB7~DB0 as output

    setRW(0);  setCD(1);				  // Write data register

	FIO0PIN2 = data;  // output data on P0.23~P0.16, as a 8bits bus

	FIO3SET = E; // E = 1	(faster)
	FIO3CLR = E; // E = 0	(faster)
	delayUs(5);
}

// Initialize LCM controller IC, UC1617
void lcdInit(void) {

    setRST(0);
    delayMs(10);
	setRST(1);
	delayMs(10);		 // Reset(hardware) 

	writeComd(0xE2);    delayUs(100);   // (22)"System Reset"
	writeComd(0x2A);    delayUs(100);	// (6) "Set Panel Loading"   9~13nF 
	writeComd(0x27);    delayUs(100);	// (5) "Set Tempature Compensation"	 -0.2%/Degree C
	writeComd(0xC4);    delayUs(100);	// (19)"Set LCD Mapping Control"	SEG1-->SEG128 ;  COM128-->COM1
	writeComd(0x89);    delayMs(100);	// (13)"Set RAM Address Control"	column++ then row++ (L->R, U->D)
	writeComd(0xA1);	delayUs(100);	// (15)"Set Line Rate"	            17.3KIPS
	writeComd(0xEB);	delayUs(100);	// (25)"Set LCD Bias Ratio"		    BIAS is 1/11
	writeComd(0x81);	delayUs(10);    // (11)"Set Vbias Potentiometer"	0~193
	writeComd(30);	    delayUs(100);	// (11)	  
	writeComd(0x2F);	delayUs(100);	// (7) "Set Pump Control"			Internal VLCD (9X PUMP)
    writeComd(0xC8);	delayUs(10);    // (20)"Set N-Line Inversion"		Disable N-line inversion
	writeComd(0x04);	delayUs(100);   // (20)
	writeComd(0xF1);	delayUs(10);    // (28)"Set COM End"		        1/128duty
	writeComd(127);	    delayUs(100);   // (28)
	writeComd(0xAF);	delayUs(10);    // (18)"Set Display Enable"			Disable sleep and 4 grayscle, enable black/white

}


// **** fillScreen ****
// Fill the screen with simple data,
// Note: for each "data" byte, one bit control one pixel. 
// (The "data" byte will actually be seperated to d11 and d12, and d11 control 4 pixels, d12 control another 4 pixels) 
// (L->R, then U->D)
void fillScreen(INT8U data) {

    INT16U i,j;
    INT8U d11=0;
	INT8U d12=0;

    writeComd(0x00);    delayUs(100);   // (4) "Set Page_C Address"		 One byte control 4 pixels
	writeComd(0x70);	delayUs(10);    // (10)"Set Row Address LSB"
	writeComd(0x60);	delayUs(100);   // (10)"Set Row Address MSB"

	
    if((data&0x80)==0) d11=d11&0xFC;    // d11&11111100b
    else               d11=d11|0x03;    // d11|00000011b
    if((data&0x40)==0) d11=d11&0xF3;    // d11&11110011b
    else               d11=d11|0x0C;    // d11|00001100b
    if((data&0x20)==0) d11=d11&0xCF;    // d11&11001111b 
    else               d11=d11|0x30;    // d11|00110000b
    if((data&0x10)==0) d11=d11&0x3F;    // d11&00111111b 
    else               d11=d11|0xC0;    // d11|11000000b
    if((data&0x08)==0) d12=d12&0xFC;    // d12&11111100b
    else               d12=d12|0x03;    // d12|00000011b
    if((data&0x04)==0) d12=d12&0xF3;    // d12&11110011b
    else               d12=d12|0x0C;    // d12|00001100b
    if((data&0x02)==0) d12=d12&0xCF;    // d12&11001111b 
    else               d12=d12|0x30;    // d12|00110000b
    if((data&0x01)==0) d12=d12&0x3F;    // d12&00111111b 
    else               d12=d12|0xC0;    // d12|11000000b
    
	for (j=0; j<128; j++) {
	    for(i=0; i<32; i++){
            writeData(d11);
            writeData(d12);
        }
	}
}

// **** cleanScreen ****
void cleanScreen(void)	{
    fillScreen(0x00);
}

//
void refreshScreen(INT8U *gData) {
    
    INT16U i;
	INT8U d11=0;
	INT8U d12=0;

	writeComd(0x00);    delayUs(100);   // (4) "Set Page_C Address"		 One byte control 4 pixels
	writeComd(0x70);	delayUs(10);    // (10)"Set Row Address LSB"
	writeComd(0x60);	delayUs(100);   // (10)"Set Row Address MSB"

    for(i=0;i<2048;i++) {
        if((gData[i]&0x80)==0) d11=d11&0xFC;    // d11&11111100b
        else                   d11=d11|0x03;    // d11|00000011b
        if((gData[i]&0x40)==0) d11=d11&0xF3;    // d11&11110011b
        else                   d11=d11|0x0C;    // d11|00001100b
        if((gData[i]&0x20)==0) d11=d11&0xCF;    // d11&11001111b 
        else                   d11=d11|0x30;    // d11|00110000b
        if((gData[i]&0x10)==0) d11=d11&0x3F;    // d11&00111111b 
        else                   d11=d11|0xC0;    // d11|11000000b
        if((gData[i]&0x08)==0) d12=d12&0xFC;    // d12&11111100b
        else                   d12=d12|0x03;    // d12|00000011b
        if((gData[i]&0x04)==0) d12=d12&0xF3;    // d12&11110011b
        else                   d12=d12|0x0C;    // d12|00001100b
        if((gData[i]&0x02)==0) d12=d12&0xCF;    // d12&11001111b 
        else                   d12=d12|0x30;    // d12|00110000b
        if((gData[i]&0x01)==0) d12=d12&0x3F;    // d12&00111111b 
        else                   d12=d12|0xC0;    // d12|11000000b

        writeData(d11);
		writeData(d12);
    } 
}


INT8U graphic_D0[2048]=	   // OD logo & PN & resolution	 for "AMG128128PR-G-W12WFDW"
{
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x7F,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x01,0xC0,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x03,0x8F,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x06,0x7F,0xEC,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x0C,0x30,0x36,0x03,0xE7,0xE3,0x3E,0xF3,0x7F,0x0F,0xCE,0xFC,0xFC,0xE0,0x77,0x18,
0x08,0x30,0x1A,0x07,0x67,0x67,0x70,0xF3,0x3C,0x0F,0xCC,0xDC,0xFC,0xC0,0x77,0x18,
0x18,0x30,0x1B,0x06,0x66,0x67,0x70,0xF3,0x18,0x1C,0xDD,0xCC,0xCC,0xC0,0xF3,0x30,
0x10,0x20,0x0D,0x06,0x66,0x66,0x60,0xF2,0x38,0x1D,0xDD,0xDD,0xCD,0xC0,0xF3,0x30,
0x10,0x60,0x0D,0x0E,0x66,0x66,0x60,0xF6,0x38,0x1D,0xDD,0xC1,0xDD,0xC1,0xF3,0x60,
0x30,0x60,0x0D,0x0E,0xEE,0xC6,0x60,0xF6,0x38,0x1D,0xDD,0xE1,0x9D,0xC1,0xF3,0xE0,
0x30,0x60,0x1D,0x0C,0xEF,0xC6,0x7D,0xFE,0x30,0x19,0xD8,0xF1,0x9D,0x83,0xB3,0xC0,
0x30,0x60,0x19,0x0C,0xCE,0xCE,0xE1,0xBE,0x30,0x19,0x98,0x71,0xF9,0x83,0x33,0xC0,
0x10,0x60,0x19,0x0C,0xCC,0xCE,0xE1,0xBC,0x30,0x39,0xB8,0x3B,0xF3,0x83,0x33,0x80,
0x10,0x60,0x1B,0x1C,0xCC,0xCC,0xC1,0xBC,0x70,0x3B,0xBB,0xBB,0x83,0x87,0xF3,0x80,
0x18,0x40,0x33,0x1C,0xCC,0xCC,0xC1,0x3C,0x70,0x3B,0xBB,0x3B,0x83,0x87,0x73,0x80,
0x08,0xC0,0x76,0x19,0xDD,0xCC,0xC1,0x1C,0x70,0x33,0xBB,0x3B,0x03,0x06,0x33,0x00,
0x0C,0xC0,0xE4,0x19,0x99,0xCC,0xC3,0x1C,0x60,0x3F,0x33,0xF3,0x03,0x0E,0x33,0x00,
0x06,0xFF,0x8C,0x1F,0x99,0xDD,0xFB,0x1C,0x60,0x3E,0x73,0xF7,0x03,0xEE,0x37,0x00,
0x03,0xFE,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x01,0xE0,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x3F,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x10,0x82,0x38,0x21,0xC7,0x08,0x71,0xCF,0x3E,0x01,0xC0,0x00,0x00,
0x00,0x00,0x00,0x28,0xC6,0x44,0x62,0x28,0x98,0x8A,0x28,0xA1,0x02,0x20,0x00,0x00,
0x00,0x00,0x00,0x28,0xC6,0x82,0xA0,0x28,0xA8,0x0A,0x28,0xA1,0x04,0x10,0x00,0x00,
0x00,0x00,0x00,0x28,0xAA,0x80,0x20,0x27,0x08,0x09,0xC8,0xBE,0x04,0x00,0x00,0x00,
0x00,0x00,0x00,0x44,0xAA,0x8E,0x20,0x48,0x88,0x12,0x2F,0x24,0x04,0x70,0x00,0x00,
0x00,0x00,0x00,0x7C,0xAA,0x82,0x20,0x88,0x88,0x22,0x28,0x22,0x74,0x10,0x00,0x00,
0x00,0x00,0x00,0x82,0x92,0x44,0x21,0x08,0x88,0x42,0x28,0x22,0x02,0x20,0x00,0x00,
0x00,0x00,0x00,0x82,0x92,0x38,0x23,0xE7,0x08,0xF9,0xC8,0x21,0x01,0xC0,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x01,0x08,0x48,0x74,0x21,0xFB,0xC8,0x42,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x01,0x14,0x58,0x8C,0x51,0x82,0x28,0xA2,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x94,0xA8,0x0A,0x52,0x82,0x14,0xA4,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x94,0x88,0x0A,0x52,0xF2,0x14,0xA4,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xA2,0x88,0x12,0x8A,0x82,0x15,0x14,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x0E,0xA2,0x88,0x22,0x8A,0x82,0x15,0x14,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x41,0x08,0x41,0x04,0x82,0x22,0x08,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x41,0x08,0xF9,0x04,0x83,0xC2,0x08,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x04,0x38,0xE0,0x00,0x43,0x8E,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x0C,0x45,0x10,0x00,0xC4,0x51,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x14,0x05,0x10,0x41,0x40,0x51,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x04,0x04,0xE0,0xE0,0x40,0x4E,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x04,0x09,0x10,0x40,0x40,0x91,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x04,0x11,0x10,0xA0,0x41,0x11,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x04,0x21,0x10,0x00,0x42,0x11,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x04,0x7C,0xE0,0x00,0x47,0xCE,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
};

INT8U graphic_D1[2048]=	   // 
{
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x67,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x61,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x80,0x40,0x00,0x01,0xFE,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x3C,0x00,0x01,0x00,0xC0,0x00,0x07,0xF7,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x7E,0x00,0x03,0x00,0x60,0x00,0x06,0x03,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC3,0x80,0x03,0x00,0x20,0x00,0x0C,0x01,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC0,0xE0,0x02,0x00,0x60,0x00,0x18,0x01,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC0,0x70,0x06,0x00,0x20,0x00,0x30,0x01,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC0,0x18,0x06,0x00,0x30,0x00,0x40,0x00,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC0,0x0C,0x06,0x00,0x30,0x00,0xC0,0x00,0xC0,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC0,0x04,0x06,0x00,0x20,0x01,0x80,0x00,0x40,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC0,0x03,0x06,0x00,0x10,0x01,0x80,0x00,0x40,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC0,0x01,0x84,0x00,0x10,0x01,0x00,0x00,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC0,0x01,0x84,0x00,0x18,0x06,0x00,0x01,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC0,0x00,0xCC,0x00,0x18,0x06,0x00,0x01,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC0,0x00,0x6C,0x00,0x10,0x08,0x00,0x01,0x80,0x3F,0x00,0x00,
0x00,0x00,0x00,0x00,0x40,0x00,0x64,0x00,0x18,0x18,0x00,0x01,0x81,0xFF,0xC0,0x00,
0x00,0x00,0x3E,0x00,0x60,0x00,0x3C,0x00,0x18,0x10,0x00,0x03,0x07,0x00,0x60,0x00,
0x00,0x00,0x7F,0xE0,0x60,0x00,0x1C,0x00,0x18,0x30,0x00,0x03,0x1E,0x00,0x60,0x00,
0x00,0x00,0x60,0xF0,0x30,0x00,0x1C,0x00,0x08,0x30,0x00,0x03,0x38,0x00,0x40,0x00,
0x00,0x00,0x60,0x0E,0x30,0x00,0x0C,0x00,0x08,0x60,0x00,0x06,0x60,0x00,0xC0,0x00,
0x00,0x00,0x60,0x03,0x90,0x00,0x06,0x00,0x08,0x60,0x00,0x07,0xC0,0x00,0xC0,0x00,
0x00,0x00,0x60,0x01,0xD8,0x00,0x06,0x00,0x08,0xC0,0x00,0x0F,0x00,0x00,0xC0,0x00,
0x00,0x00,0x40,0x00,0xE8,0x00,0x06,0x00,0x0C,0xC0,0x00,0x0E,0x00,0x00,0x80,0x00,
0x00,0x00,0x20,0x00,0x34,0x00,0x02,0x00,0x04,0x80,0x00,0x0C,0x00,0x00,0x80,0x00,
0x00,0x00,0x30,0x00,0x3E,0x00,0x03,0x00,0x0D,0x80,0x00,0x38,0x00,0x03,0x00,0x00,
0x00,0x00,0x30,0x00,0x1E,0x00,0x03,0x00,0x0D,0x80,0x00,0x30,0x00,0x03,0x00,0x00,
0x00,0x00,0x18,0x00,0x0F,0x00,0x01,0x00,0x0F,0x00,0x00,0x60,0x00,0x06,0x00,0x00,
0x00,0x00,0x08,0x00,0x07,0x80,0x01,0x80,0x0B,0x00,0x00,0xC0,0x00,0x06,0x00,0x00,
0x03,0xFF,0xFC,0x00,0x03,0x80,0x00,0x80,0x0E,0x00,0x00,0xC0,0x00,0x0C,0x1F,0xF8,
0x07,0xFF,0xEE,0x00,0x01,0xC0,0x00,0xC0,0x0E,0x00,0x00,0x80,0x00,0x18,0xF8,0x1C,
0x06,0x00,0x07,0x00,0x00,0xE0,0x00,0xC0,0x0E,0x00,0x03,0x80,0x00,0x1B,0x80,0x04,
0x06,0x00,0x01,0x00,0x00,0x70,0x00,0xC0,0x04,0x00,0x03,0x00,0x00,0x1B,0x00,0x04,
0x02,0x00,0x01,0x80,0x00,0x38,0x00,0x60,0x0C,0x00,0x06,0x00,0x00,0x7C,0x00,0x08,
0x03,0x00,0x01,0xC0,0x00,0x1C,0x00,0x60,0x0C,0x00,0x0C,0x00,0x00,0xF0,0x00,0x0C,
0x03,0x00,0x00,0xE0,0x00,0x0C,0x00,0x60,0x18,0x00,0x18,0x00,0x00,0xC0,0x00,0x04,
0x01,0x80,0x00,0x70,0x00,0x06,0x00,0x30,0x10,0x00,0x18,0x00,0x01,0x80,0x00,0x08,
0x00,0xC0,0x00,0x38,0x00,0x07,0x00,0x30,0x18,0x00,0x30,0x00,0x03,0x00,0x00,0x38,
0x00,0x60,0x00,0x1C,0x00,0x03,0x00,0x30,0x18,0x00,0x60,0x00,0x02,0x00,0x00,0x30,
0x00,0x20,0x00,0x0E,0x00,0x01,0x80,0x18,0x30,0x00,0x40,0x00,0x06,0x00,0x00,0xE0,
0x00,0x38,0x00,0x03,0x00,0x00,0xC0,0x18,0x30,0x00,0x80,0x00,0x0C,0x00,0x00,0x80,
0x00,0x1C,0x00,0x03,0x80,0x00,0xE0,0x18,0x30,0x03,0x80,0x00,0x18,0x00,0x07,0x00,
0x00,0x07,0x00,0x01,0xC0,0x00,0x60,0x0C,0x70,0x03,0x00,0x00,0x70,0x00,0x06,0x00,
0x00,0x03,0x80,0x00,0xC0,0x00,0x20,0x08,0x60,0x06,0x00,0x00,0xE0,0x00,0x3D,0xB8,
0x00,0x00,0xE0,0x00,0x38,0x00,0x38,0x0C,0x40,0x0C,0x00,0x00,0xC0,0x00,0xFD,0xDE,
0x00,0x00,0x78,0x00,0x0C,0x00,0x1C,0x04,0x60,0x18,0x00,0x03,0x00,0x01,0xC0,0x03,
0x00,0x00,0x1E,0x00,0x0F,0x00,0x0C,0x04,0x60,0x18,0x00,0x0E,0x00,0x0F,0x00,0x01,
0x03,0xFF,0xFF,0xF8,0x03,0x80,0x06,0x02,0xC0,0x30,0x00,0x1C,0x00,0x7C,0x00,0x01,
0x07,0xFF,0xFF,0x7F,0x41,0xE0,0x07,0x06,0xC0,0x60,0x00,0x30,0x03,0xE0,0x00,0x01,
0x3C,0x00,0x00,0x03,0xF8,0x70,0x03,0x83,0xE0,0xC0,0x00,0xE0,0x3E,0x00,0x00,0x01,
0x70,0x00,0x00,0x00,0x0E,0x0C,0x01,0x87,0xFF,0xE0,0x03,0xC1,0xF8,0x00,0x00,0x02,
0x60,0x00,0x00,0x00,0x07,0x8E,0x01,0xCF,0xFF,0xE0,0x07,0x0F,0x40,0x00,0x00,0x06,
0x60,0x00,0x00,0x00,0x00,0xC3,0x80,0x7F,0xFF,0xC0,0x18,0x7A,0x00,0x00,0x00,0x0C,
0x60,0x00,0x00,0x00,0x00,0x60,0xC0,0x7F,0xFF,0xC0,0x1F,0xF0,0x00,0x00,0x00,0x38,
0x30,0x00,0x00,0x00,0x00,0x3E,0x70,0x7F,0xFF,0xF0,0xF7,0x00,0x00,0x00,0x00,0x70,
0x1C,0x00,0x00,0x00,0x00,0x07,0xB8,0xFF,0xFF,0xFD,0xC0,0x00,0x00,0x00,0x01,0xC0,
0x0E,0x00,0x00,0x00,0x00,0x01,0xCF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x0F,0x00,
0x03,0x80,0x00,0x00,0x00,0x00,0x67,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,0x7C,0x00,
0x01,0xE0,0x00,0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFC,0xEF,0xFF,0xFF,0xFF,0xF0,0x00,
0x00,0x78,0x00,0x00,0x00,0x00,0x1F,0xFF,0xFF,0xFF,0xFF,0x00,0xFF,0xF7,0x00,0x00,
0x00,0x1E,0x00,0x00,0x00,0x0F,0x07,0xFF,0xFF,0xF8,0x00,0x00,0x01,0xFC,0x00,0x00,
0x00,0x07,0x80,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x1F,0x80,0x00,
0x00,0x01,0xFE,0x1F,0xFD,0xC0,0x3F,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x01,0xE0,0x00,
0x00,0x00,0x3F,0xFF,0x80,0x07,0xDF,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x00,0x78,0x00,
0x00,0x00,0x0F,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x00,0x1E,0x00,
0x00,0x00,0x76,0x00,0x01,0xFC,0x03,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x05,0x80,
0x00,0x01,0xE0,0x00,0x07,0xC0,0x01,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,0x01,0xE0,
0x00,0x0F,0x80,0x00,0x1D,0x00,0x00,0x7F,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x70,
0x00,0x38,0x00,0x00,0x78,0x00,0x00,0x7F,0xFF,0xF1,0xC0,0x00,0x00,0x00,0x00,0x18,
0x00,0xE0,0x00,0x00,0xE0,0x00,0x00,0x7F,0xFF,0xF0,0xF8,0x00,0x00,0x00,0x00,0x0C,
0x01,0xC0,0x00,0x07,0x80,0x00,0x00,0xFF,0xFF,0xF8,0x0F,0x00,0x00,0x00,0x00,0x02,
0x07,0x00,0x00,0x0E,0x00,0x00,0x01,0xFF,0xF0,0x1C,0x06,0xF0,0x00,0x00,0x00,0x06,
0x0E,0x00,0x00,0x38,0x00,0x00,0x07,0x30,0x38,0x0E,0x00,0x7F,0x80,0x00,0x00,0x0C,
0x18,0x00,0x00,0x60,0x00,0x00,0x0C,0x30,0x10,0x06,0x00,0x07,0xFE,0x00,0x00,0x78,
0x30,0x00,0x01,0xC0,0x00,0x00,0x1C,0x60,0x10,0x03,0x80,0x00,0x3F,0xF8,0x1B,0xE0,
0x60,0x00,0x03,0x80,0x00,0x00,0x38,0x60,0x18,0x01,0xC0,0x00,0x01,0x7F,0xFF,0x80,
0xC0,0x00,0x07,0x00,0x00,0x00,0x60,0xC0,0x18,0x00,0xF0,0x00,0x00,0x07,0xE0,0x00,
0x60,0x00,0x0C,0x00,0x00,0x00,0xC0,0xC0,0x18,0x00,0x78,0x00,0x00,0x00,0x70,0x00,
0x70,0x00,0x30,0x00,0x00,0x01,0x80,0x80,0x08,0x00,0x6E,0x00,0x00,0x00,0x30,0x00,
0x1F,0x00,0x70,0x00,0x00,0x03,0x01,0x80,0x04,0x00,0x37,0x80,0x00,0x00,0x08,0x00,
0x07,0xFF,0xE0,0x00,0x00,0x0E,0x03,0x00,0x0C,0x00,0x19,0xE0,0x00,0x00,0x0C,0x00,
0x00,0x3F,0xC0,0x00,0x00,0x1C,0x03,0x00,0x0C,0x00,0x0C,0x70,0x00,0x00,0x04,0x00,
0x00,0x01,0x80,0x00,0x00,0x30,0x06,0x00,0x04,0x00,0x0C,0x1C,0x00,0x00,0x06,0x00,
0x00,0x03,0x00,0x00,0x00,0xE0,0x06,0x00,0x06,0x00,0x06,0x0F,0x00,0x00,0x06,0x00,
0x00,0x03,0x00,0x00,0x07,0xC0,0x0C,0x00,0x0E,0x00,0x03,0x03,0xC0,0x00,0x06,0x00,
0x00,0x06,0x00,0x00,0x1E,0x00,0x0C,0x00,0x0E,0x00,0x01,0x00,0xE0,0x00,0x06,0x00,
0x00,0x06,0x00,0x00,0xF8,0x00,0x08,0x00,0x0F,0x00,0x01,0x00,0x3C,0x00,0x06,0x00,
0x00,0x0C,0x00,0x07,0xE0,0x00,0x18,0x00,0x0B,0x00,0x00,0xC0,0x1F,0x80,0x0C,0x00,
0x00,0x08,0x00,0x3F,0xC0,0x00,0x30,0x00,0x0F,0x00,0x00,0xC0,0x07,0xF7,0xF8,0x00,
0x00,0x0E,0x1F,0x78,0xC0,0x00,0x10,0x00,0x0D,0x80,0x00,0x60,0x00,0xDF,0xE0,0x00,
0x00,0x07,0xFF,0x80,0x80,0x00,0x60,0x00,0x0D,0x80,0x00,0x40,0x00,0x60,0x00,0x00,
0x00,0x00,0x00,0x01,0x80,0x00,0x60,0x00,0x1C,0xC0,0x00,0x60,0x00,0x20,0x00,0x00,
0x00,0x00,0x00,0x01,0x00,0x00,0xE0,0x00,0x18,0xC0,0x00,0x30,0x00,0x30,0x00,0x00,
0x00,0x00,0x00,0x01,0x00,0x00,0xE0,0x00,0x18,0x60,0x00,0x10,0x00,0x30,0x00,0x00,
0x00,0x00,0x00,0x02,0x00,0x00,0xC0,0x00,0x18,0x60,0x00,0x10,0x00,0x18,0x00,0x00,
0x00,0x00,0x00,0x06,0x00,0x03,0xC0,0x00,0x18,0x20,0x00,0x10,0x00,0x08,0x00,0x00,
0x00,0x00,0x00,0x06,0x00,0x07,0xC0,0x00,0x38,0x10,0x00,0x18,0x00,0x18,0x00,0x00,
0x00,0x00,0x00,0x04,0x00,0x06,0xC0,0x00,0x38,0x18,0x00,0x08,0x00,0x08,0x00,0x00,
0x00,0x00,0x00,0x0C,0x00,0x0C,0x40,0x00,0x38,0x18,0x00,0x0C,0x00,0x08,0x00,0x00,
0x00,0x00,0x00,0x0C,0x00,0x18,0xC0,0x00,0x38,0x0C,0x00,0x06,0x00,0x08,0x00,0x00,
0x00,0x00,0x00,0x08,0x00,0x10,0xC0,0x00,0x38,0x06,0x00,0x0F,0x80,0x18,0x00,0x00,
0x00,0x00,0x00,0x18,0x00,0x60,0x80,0x00,0xD8,0x06,0x00,0x0D,0xF0,0x10,0x00,0x00,
0x00,0x00,0x00,0x18,0x00,0xC1,0x80,0x00,0xD8,0x03,0x00,0x08,0x7F,0xF0,0x00,0x00,
0x00,0x00,0x00,0x18,0x01,0x81,0x80,0x00,0xCC,0x01,0x80,0x0C,0x07,0xB0,0x00,0x00,
0x00,0x00,0x00,0x10,0x07,0x01,0x80,0x00,0x8C,0x00,0x80,0x0C,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x18,0x1C,0x01,0x80,0x01,0x0C,0x00,0xC0,0x0C,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x18,0x78,0x01,0x80,0x03,0x84,0x00,0x60,0x0C,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x1D,0xE8,0x01,0x80,0x03,0x86,0x00,0x30,0x0C,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x0B,0x90,0x01,0x80,0x05,0x86,0x00,0x1C,0x18,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x30,0x02,0xC0,0x0D,0x83,0x00,0x07,0x18,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x20,0x06,0xC0,0x0D,0x83,0x00,0x0F,0xF0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x10,0x1C,0xC0,0x19,0x01,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x18,0x30,0x40,0x31,0x01,0x80,0x0C,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x0D,0xE0,0x60,0x71,0x80,0xC0,0x0C,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x07,0xC0,0x20,0xE1,0x80,0x40,0x0C,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x33,0x81,0x80,0x60,0x18,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0x01,0x80,0x60,0x10,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x80,0x38,0x30,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0x37,0xE0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0x63,0xC0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x31,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1B,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0E,0x00,0x00,0x00,0x00,0x00,0x00,0x00
};

INT8U graphic_D2[2048]=	   // 
{
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x80,0x40,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xC0,0xE0,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xC0,0xE0,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xC0,0xE0,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xC1,0xC0,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xC1,0xC0,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0xC1,0xC0,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0xC1,0xC0,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xC1,0xC3,0x80,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0xE3,0x80,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0xE3,0x88,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE1,0xE3,0x9C,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE1,0xE7,0x1C,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE1,0xE7,0x38,0x60,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE1,0xCF,0x38,0xE0,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xE1,0xCE,0x71,0xC0,0x00,
0x00,0x1C,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xE1,0xCE,0xE3,0x80,0x00,
0x00,0x1E,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE1,0xDF,0xF7,0x00,0x00,
0x00,0x0E,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xE3,0xFF,0xFF,0x80,0x00,
0x00,0x0E,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xE3,0xFF,0xFF,0xF0,0x00,
0x00,0x0F,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xE3,0xFF,0xFF,0xF0,0x00,
0x00,0x07,0x31,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xE7,0xFF,0xFF,0xE0,0x00,
0x00,0x07,0x73,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xE7,0xFF,0xFF,0xE0,0x00,
0x00,0x07,0xF3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xE0,0x00,
0x00,0x07,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xF0,0x00,
0x00,0x03,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xF0,0x00,
0x00,0x03,0xFF,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xE0,0x00,
0x00,0x03,0xFF,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xC0,0x00,
0x00,0x01,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0x80,0x00,
0x00,0x01,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0x80,0x00,
0x00,0x00,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0x80,0x00,
0x00,0x00,0x7F,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x03,0xFF,0xFF,0xFF,0xE0,0x00,
0x00,0x00,0x7F,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x03,0xFF,0xFF,0xFF,0xC0,0x00,
0x00,0x00,0x7F,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x03,0xFF,0xFF,0xFF,0xF0,0x00,
0x00,0x00,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x03,0xFF,0xFF,0xFF,0xF0,0x00,
0x00,0x00,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x00,0x00,0x47,0xFF,0xFF,0xFF,0xF0,0x00,
0x00,0x00,0x7F,0xFF,0xFF,0x80,0x00,0x00,0x00,0x00,0xC7,0xFF,0xFF,0xFF,0xF0,0x00,
0x00,0x00,0x7F,0xFF,0xFF,0x80,0x00,0x00,0x00,0x00,0xCF,0xFF,0xFF,0xFF,0xF0,0x00,
0x00,0x00,0x1F,0xFF,0xFF,0x80,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,
0x00,0x00,0x0F,0xFF,0xFF,0x80,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,
0x00,0x00,0x03,0xFF,0xFF,0x80,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,
0x00,0x00,0x00,0xFF,0xFF,0x90,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,
0x00,0x00,0x00,0x7F,0xFF,0xF8,0x00,0x00,0x00,0x03,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,
0x00,0x00,0x00,0x3F,0xFF,0xF8,0x00,0x00,0x00,0x03,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,
0x00,0x00,0x00,0x0F,0xFF,0xF8,0x00,0x00,0x00,0x03,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,
0x00,0x00,0x00,0x0F,0xFF,0xF8,0x00,0x00,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,
0x00,0x00,0x00,0x07,0xFF,0xF8,0x00,0x00,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,
0x00,0x00,0x00,0x03,0xFF,0xFC,0x00,0x00,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,
0x00,0x00,0x00,0x03,0xFF,0xFC,0x00,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,
0x00,0x00,0x00,0x01,0xFF,0xFC,0x00,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,
0x00,0x00,0x00,0x01,0xFF,0xFC,0x00,0x00,0x00,0x1F,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,
0x00,0x00,0x00,0x01,0xFF,0xFF,0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,
0x00,0x00,0x00,0x00,0xFF,0xFF,0x80,0x00,0x00,0x7F,0xFF,0xFF,0xFF,0xFF,0x80,0x00,
0x00,0x00,0x00,0x00,0xFF,0xFF,0x80,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,
0x00,0x00,0x00,0x00,0xFF,0xFF,0xC0,0x00,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,
0x00,0x00,0x00,0x00,0xFF,0xFF,0xC0,0x00,0x03,0xFF,0xFF,0xFF,0xFF,0xFE,0x00,0x00,
0x00,0x00,0x00,0x00,0xFF,0xFF,0xC0,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x00,
0x00,0x00,0x00,0x00,0xFF,0xFF,0xC0,0x00,0x1F,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x00,
0x00,0x00,0x00,0x00,0xFF,0xFF,0xC0,0x00,0x7F,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x00,
0x00,0x00,0x00,0x00,0x7F,0xFF,0xE0,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x00,
0x00,0x00,0x00,0x00,0x7F,0xFF,0xF0,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x00,
0x00,0x00,0x00,0x00,0x3F,0xFF,0xF0,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x00,
0x00,0x00,0x00,0x00,0x3F,0xFF,0xF0,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x00,
0x00,0x00,0x00,0x00,0x3F,0xFF,0xF0,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x00,
0x00,0x00,0x00,0x00,0x1F,0xFF,0xF0,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x00,
0x00,0x00,0x00,0x00,0x1F,0xFF,0xF1,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x00,
0x00,0x00,0x00,0x00,0x1F,0xFF,0xF3,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,
0x00,0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,
0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,
0x00,0x00,0x00,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,0x00,
0x00,0x00,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,0x00,
0x00,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,0x00,
0x00,0x00,0x00,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x00,0x00,
0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,
0x00,0x00,0x00,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x00,0x00,0x00,
0x00,0x00,0x00,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x00,
0x00,0x00,0x00,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x00,
0x00,0x00,0x00,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x00,
0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,0x00,0x00,
0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x7E,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x7C,0x07,0xFF,0xFF,0xFF,0xFF,0x9F,0xF8,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x78,0x03,0xFF,0xFF,0xFF,0xFF,0x8E,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x70,0x01,0xFF,0xFF,0xFF,0xFF,0x86,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x30,0x00,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x30,0x00,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x03,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFE,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x7F,0xF1,0xFF,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x7F,0xE1,0xFF,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x00,
0x00,0x00,0x0F,0xFF,0xFF,0xC1,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,
0x00,0x00,0x1F,0xFF,0xFF,0x81,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x00,0x00,0x00,0x00,
0x00,0x00,0x37,0xFF,0xFE,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x00,0x00,0x00,0x00,
0x00,0x00,0x10,0x7F,0xC0,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,
0x00,0x00,0x10,0x63,0x80,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,
0x00,0x00,0x10,0x61,0x80,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x01,0x80,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x01,0x80,0x0F,0xFF,0x7F,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x01,0x80,0x0F,0xFE,0x3F,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x03,0x00,0x0F,0xFE,0x3F,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x1E,0x00,0x0F,0xFE,0x1F,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x0F,0xFE,0x0E,0xFF,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xFF,0xFC,0x00,0x7F,0xFF,0xEF,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x1F,0xFE,0xC0,0x00,0x7F,0xFF,0xC4,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x1F,0xFC,0x00,0x00,0x03,0xE6,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x7F,0xFC,0x00,0x00,0x01,0xC2,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xFF,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xF0,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC1,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC1,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC1,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
};

INT8U graphic_D3[2048]=	   // 
{
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x03,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x5F,0xA0,
0x0F,0xFF,0xFE,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x18,0x00,0x00,0x3F,0xFF,0xF0,
0x1F,0xFF,0xFF,0x80,0x00,0x0C,0x00,0x00,0x00,0x00,0x38,0x00,0x00,0xFF,0xFF,0xF8,
0x1F,0xFF,0xFF,0xA0,0x00,0x06,0x00,0x00,0x00,0x00,0x38,0x00,0x01,0xFF,0xFF,0xFC,
0x3F,0xFF,0xFF,0xF8,0x00,0x06,0x00,0x00,0x00,0x00,0x70,0x00,0x1F,0xFF,0xFF,0xFE,
0x1F,0xFF,0xFF,0xFC,0x00,0x07,0x00,0x00,0x00,0x00,0x60,0x00,0x3F,0xFF,0xFF,0xFE,
0x7F,0xFF,0xFF,0xFF,0x80,0x03,0x00,0x00,0x00,0x00,0x60,0x00,0x7F,0xFF,0xFF,0xFE,
0x7F,0xFF,0xFF,0xFF,0xA0,0x03,0x80,0x00,0x00,0x00,0xC0,0x03,0xFF,0xFF,0xFF,0xFE,
0x3F,0xFF,0xFF,0xFF,0xF0,0x01,0x80,0x00,0x00,0x00,0xC0,0x07,0xFF,0xFF,0xFF,0xFE,
0x3F,0xFF,0xFF,0xFF,0xFC,0x01,0xC0,0x00,0x00,0x00,0xC0,0x1F,0xFF,0xFF,0xFF,0xFE,
0x3F,0xFF,0xFF,0xFF,0xFE,0x00,0xC0,0x00,0x00,0x01,0x80,0x3F,0xFF,0xFF,0xFF,0xFC,
0x1F,0xFF,0xFF,0xFF,0xFE,0x00,0xC0,0x00,0x00,0x01,0x80,0x7F,0xFF,0xFF,0xFF,0xFC,
0x0F,0xFF,0xFF,0xFF,0xFF,0x80,0x60,0x00,0x00,0x03,0x01,0xFF,0xFF,0xFF,0xFF,0xFC,
0x1F,0xFF,0xFF,0xFF,0xFF,0xE0,0x60,0x00,0x00,0x03,0x03,0xFD,0xFF,0xFF,0xFF,0xF8,
0x0F,0xFF,0xFF,0xFF,0xD5,0xF0,0x30,0x00,0x00,0x07,0x07,0xFF,0xFF,0xFF,0xFF,0xF8,
0x0F,0xFF,0xFF,0xFF,0xF3,0xF8,0x30,0x00,0x00,0x06,0x0F,0xE3,0xFF,0xFF,0xFF,0xF0,
0x07,0xFF,0xFF,0xFF,0x65,0xFC,0x18,0x00,0x00,0x0E,0x17,0xC7,0xFF,0xFF,0xFF,0xF0,
0x07,0xFF,0xFF,0xEC,0x00,0xFE,0x18,0x00,0x00,0x0C,0x3F,0x00,0xFF,0xFF,0xFF,0xE0,
0x03,0xFF,0xFF,0xFE,0x00,0x7F,0x0C,0x00,0x00,0x18,0x7E,0x00,0x1F,0xFF,0xFF,0xE0,
0x01,0xFF,0xFF,0xFF,0x00,0x3F,0x8C,0x00,0x00,0x18,0xFE,0x00,0x3D,0xFF,0xFF,0xE0,
0x03,0xFF,0xFF,0xF1,0x00,0x1F,0x86,0x00,0x00,0x30,0xFC,0x00,0x7F,0xFF,0xFF,0xC0,
0x01,0xFF,0xFF,0xFE,0x00,0x07,0xC6,0x00,0x00,0x71,0xF8,0x00,0x3F,0xFF,0xFF,0xC0,
0x01,0xFF,0xFF,0xFA,0x00,0x03,0xE3,0x00,0x00,0x63,0xF0,0x00,0x3F,0xFF,0xFF,0xC0,
0x00,0xFF,0xFF,0xFC,0x00,0x01,0xF3,0x00,0x00,0xC7,0xE0,0x00,0x1F,0xFF,0xFF,0x80,
0x00,0xFF,0xFF,0xFD,0x80,0x01,0xF1,0x80,0x00,0xC7,0xC0,0x00,0x1F,0xFF,0xFF,0x80,
0x00,0xFF,0xFF,0xF3,0x80,0x01,0xF9,0xC0,0x01,0x8F,0x80,0x00,0x1B,0xFF,0xFF,0x80,
0x00,0x7F,0xFF,0xFC,0x00,0x00,0xFC,0xC0,0x01,0x9E,0x80,0x00,0x1F,0xFF,0xFF,0x00,
0x00,0x7F,0xFF,0xF8,0x00,0x00,0x7C,0x60,0x03,0x1F,0x00,0x00,0x0F,0xFF,0xFF,0x00,
0x00,0x7F,0xFF,0xFF,0xE0,0x00,0x3E,0x60,0x03,0x3E,0x00,0x03,0xFF,0xFF,0xFF,0x00,
0x00,0x3F,0xFF,0xFE,0xE0,0x00,0x17,0x30,0x06,0x7E,0x00,0x03,0xFF,0xFF,0xFF,0x00,
0x00,0x7F,0xFF,0xF0,0x00,0x00,0x0F,0x38,0x06,0x7C,0x00,0x00,0x0F,0xFF,0xFF,0x00,
0x00,0x7F,0xFF,0xFE,0x00,0x00,0x0E,0x98,0x0C,0xF8,0x00,0x00,0x3F,0xFF,0xFF,0x00,
0x00,0x7F,0xFF,0xFF,0xE0,0x00,0x03,0x9C,0x0C,0x60,0x00,0x03,0xFF,0xFF,0xFF,0x00,
0x00,0x7F,0xFF,0xFF,0xE0,0x00,0x03,0xCC,0x18,0xF0,0x00,0x03,0xFF,0xFF,0xFE,0x00,
0x00,0x3F,0xFF,0xFC,0x00,0x00,0x03,0xCC,0x39,0xE0,0x00,0x01,0x7F,0xFF,0xFE,0x00,
0x00,0x3F,0xFF,0xE0,0x00,0x00,0x01,0xE7,0xF0,0xC0,0x00,0x00,0x1F,0xFF,0xFE,0x00,
0x00,0x3F,0xFF,0x9C,0xC0,0x00,0x01,0xE7,0xF3,0xC0,0x00,0x00,0x01,0xFF,0xFE,0x00,
0x00,0x3F,0xFD,0xFF,0xF8,0x00,0x00,0xE7,0xF1,0x80,0x00,0x1B,0xFE,0xFF,0xFE,0x00,
0x00,0x3F,0xFF,0xFF,0xE6,0x00,0x00,0x27,0xF3,0x00,0x00,0x0F,0xFF,0xFF,0xFE,0x00,
0x00,0x3F,0xFF,0xFD,0x00,0x00,0x00,0x77,0xF7,0x00,0x00,0x00,0xFF,0xFF,0xFE,0x00,
0x00,0x3F,0xFF,0xE8,0x00,0x00,0x00,0x37,0xF6,0x00,0x00,0x00,0x07,0xFF,0xFE,0x00,
0x00,0x0F,0xFF,0xE0,0x00,0x00,0x00,0x3F,0xEE,0x00,0x00,0x00,0x03,0xFF,0xFC,0x00,
0x00,0x1F,0xFF,0x85,0x80,0x00,0x00,0x1F,0xF4,0x00,0x00,0x00,0xF1,0xFF,0xFC,0x00,
0x00,0x1F,0xFF,0xFF,0x80,0x00,0x06,0x0F,0xF9,0x30,0x00,0x00,0xFE,0xFF,0xFC,0x00,
0x00,0x07,0xFF,0xFE,0x00,0x00,0x07,0xD7,0xF0,0xF0,0x00,0x00,0x7F,0xFF,0xFC,0x00,
0x00,0x0F,0xFF,0xF8,0x00,0x00,0x01,0xDF,0xFF,0xC0,0x00,0x00,0x1F,0xFF,0xF8,0x00,
0x00,0x0F,0xFF,0xE0,0x00,0x00,0x00,0xFF,0xFF,0x80,0x00,0x00,0x0F,0xFF,0xF8,0x00,
0x00,0x07,0xFF,0xC0,0x00,0x00,0x00,0x7F,0xFE,0x00,0x00,0x00,0x00,0xFF,0xE0,0x00,
0x00,0x07,0xFF,0xF0,0x00,0xFF,0x7F,0xFF,0xFF,0xFF,0xBF,0x80,0x07,0xFF,0xE0,0x00,
0x00,0x03,0xFF,0xFF,0xBF,0xFF,0xFF,0xFF,0xFF,0xFF,0xBF,0xDE,0x7F,0xFF,0xC0,0x00,
0x00,0x00,0x7F,0xFF,0xF7,0xF0,0x00,0x7F,0xFE,0x00,0x03,0xF7,0xFF,0xFF,0x80,0x00,
0x00,0x00,0x6E,0xFF,0xFF,0x80,0x01,0xFF,0xFF,0x80,0x00,0x3F,0xFD,0xBE,0x00,0x00,
0x00,0x00,0x03,0xFF,0xFF,0x80,0x01,0xFF,0xFF,0x80,0x00,0xFF,0xFF,0xE0,0x00,0x00,
0x00,0x00,0x01,0xFF,0xFB,0x00,0x00,0x1F,0xFC,0x00,0x00,0xBF,0xFD,0xC0,0x00,0x00,
0x00,0x00,0x03,0xFF,0xFF,0x80,0x00,0x07,0xF8,0x00,0x00,0x1F,0xFF,0xE0,0x00,0x00,
0x00,0x00,0x07,0xFF,0xFF,0x80,0x00,0x0F,0xF8,0x00,0x00,0x7F,0xFF,0xF8,0x00,0x00,
0x00,0x00,0x0F,0xFF,0xFC,0x00,0x00,0x07,0xE0,0x00,0x00,0x7F,0xFF,0xF8,0x00,0x00,
0x00,0x00,0x0F,0xFF,0xF0,0x00,0x00,0x07,0xF0,0x00,0x00,0x0F,0xFF,0xF8,0x00,0x00,
0x00,0x00,0x0F,0xFF,0xE0,0x00,0x00,0x0B,0xF8,0x00,0x00,0x05,0xFF,0xFC,0x00,0x00,
0x00,0x00,0x1F,0xFF,0xE0,0x00,0x00,0x0F,0xF8,0x00,0x00,0x07,0xFF,0xFC,0x00,0x00,
0x00,0x00,0x3F,0xFF,0xE0,0x00,0x00,0x0F,0xFC,0x00,0x00,0x07,0xFF,0xFA,0x00,0x00,
0x00,0x00,0x3F,0xFF,0xC0,0x00,0x00,0x0F,0xFC,0x00,0x00,0x07,0xFF,0xFE,0x00,0x00,
0x00,0x00,0x7F,0xFE,0x00,0x00,0x00,0x3F,0xFE,0x00,0x00,0x01,0xBF,0xFE,0x00,0x00,
0x00,0x00,0x7F,0xFF,0x00,0x00,0x00,0x1F,0xD2,0x00,0x00,0x00,0x7F,0xFF,0x00,0x00,
0x00,0x00,0x7F,0xFC,0x00,0x00,0x00,0x77,0xF6,0x00,0x00,0x00,0x1F,0xFF,0x00,0x00,
0x00,0x00,0x7F,0xFB,0xC0,0x00,0x00,0x37,0xF7,0x00,0x00,0x01,0xBF,0xFE,0x00,0x00,
0x00,0x00,0x7F,0xFF,0xC0,0x00,0x00,0x37,0xF7,0x00,0x00,0x01,0xFF,0xFE,0x00,0x00,
0x00,0x00,0x7F,0xFE,0x80,0x00,0x00,0xF7,0xF7,0x00,0x00,0x01,0xFF,0xFE,0x00,0x00,
0x00,0x00,0x7F,0xFF,0x1C,0x00,0x00,0x63,0xE3,0x00,0x00,0x10,0xFF,0xFE,0x00,0x00,
0x00,0x00,0x7F,0xFE,0x18,0x00,0x00,0xE7,0xE3,0x80,0x00,0x1C,0xFF,0xFF,0x00,0x00,
0x00,0x00,0xBF,0xFE,0xFC,0x00,0x00,0xE7,0xE3,0x80,0x00,0x1C,0x7F,0xFE,0x00,0x00,
0x00,0x00,0xFF,0xFF,0xF8,0x00,0x01,0xC7,0xE3,0x80,0x00,0x0F,0xBF,0xFF,0x00,0x00,
0x00,0x00,0xFF,0xFE,0xF8,0x00,0x01,0xC3,0xE1,0x80,0x00,0x07,0xDF,0xFF,0x80,0x00,
0x00,0x00,0xFF,0xFF,0xF6,0x00,0x01,0xC3,0xE1,0xC0,0x00,0x37,0xFF,0xFF,0x00,0x00,
0x00,0x00,0x7F,0xFF,0xE7,0x80,0x00,0x81,0xC1,0xC0,0x00,0x3F,0xFF,0xFF,0x00,0x00,
0x00,0x00,0x3F,0xFF,0xFF,0x00,0x01,0x80,0x01,0x40,0x00,0x7F,0xFF,0xFE,0x00,0x00,
0x00,0x00,0x07,0xFF,0xFF,0x00,0x01,0x80,0x00,0xC0,0x00,0x7F,0xFF,0xF0,0x00,0x00,
0x00,0x00,0x0F,0xFF,0xFF,0x00,0x01,0x80,0x00,0xC0,0x00,0x7F,0xFF,0xF0,0x00,0x00,
0x00,0x00,0x0F,0xFF,0xFF,0x70,0x03,0x80,0x00,0xE0,0x07,0x7F,0xFF,0xF8,0x00,0x00,
0x00,0x00,0x07,0xFF,0xFE,0xE0,0x03,0x00,0x00,0xE0,0x07,0xBF,0xFF,0xF0,0x00,0x00,
0x00,0x00,0x07,0xFF,0xFB,0xE0,0x03,0x00,0x00,0x60,0x05,0xFF,0xFF,0xF0,0x00,0x00,
0x00,0x00,0x07,0xFF,0xFF,0xE0,0x07,0x00,0x00,0x70,0x01,0xBF,0xFF,0xF0,0x00,0x00,
0x00,0x00,0x07,0xFF,0xFF,0xE0,0x46,0x00,0x00,0x70,0x03,0xFF,0xFF,0xF8,0x00,0x00,
0x00,0x00,0x0F,0xFF,0xFF,0xE0,0xEE,0x00,0x00,0x33,0x0F,0xFF,0xFF,0xF8,0x00,0x00,
0x00,0x00,0x0F,0xFF,0xFF,0xFA,0x6E,0x00,0x00,0x39,0x0F,0xFF,0xFF,0xF0,0x00,0x00,
0x00,0x00,0x0F,0xFF,0xFF,0xF9,0xCE,0x00,0x00,0x3D,0x1F,0xFF,0xFF,0xF8,0x00,0x00,
0x00,0x00,0x07,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x2F,0xFF,0xFF,0xFF,0xF0,0x00,0x00,
0x00,0x00,0x03,0xFF,0xFF,0xFF,0xF8,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xE0,0x00,0x00,
0x00,0x00,0x01,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x1F,0xFF,0xFF,0xFF,0xC0,0x00,0x00,
0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x1F,0xFF,0xFF,0xFF,0x00,0x00,0x00,
0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x1F,0xFF,0xFF,0xFF,0x00,0x00,0x00,
0x00,0x00,0x00,0x7F,0xFF,0xFF,0xFC,0x00,0x00,0x1F,0xFF,0xFF,0xFF,0x00,0x00,0x00,
0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFC,0x00,0x00,0x1F,0xFF,0xFF,0xFC,0x00,0x00,0x00,
0x00,0x00,0x00,0x7F,0xFF,0xFF,0xF8,0x00,0x00,0x1F,0xFF,0xFF,0xFC,0x00,0x00,0x00,
0x00,0x00,0x00,0x7F,0xFF,0xFF,0xF0,0x00,0x00,0x0F,0xFF,0xFF,0xFE,0x00,0x00,0x00,
0x00,0x00,0x00,0x7F,0xFF,0xFF,0xE0,0x00,0x00,0x03,0xFF,0xFF,0xFC,0x00,0x00,0x00,
0x00,0x00,0x00,0x7F,0xFF,0xFF,0xC0,0x00,0x00,0x00,0xFF,0xFF,0xFE,0x00,0x00,0x00,
0x00,0x00,0x00,0x7F,0xFF,0xFF,0x80,0x00,0x00,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,
0x00,0x00,0x00,0x3F,0xFF,0xFF,0x00,0x00,0x00,0x00,0xFF,0xFF,0xDF,0x00,0x00,0x00,
0x00,0x00,0x00,0x7E,0x0D,0xEA,0x00,0x00,0x00,0x00,0x3F,0xFC,0x1E,0x00,0x00,0x00,
0x00,0x00,0x00,0xF8,0x00,0x70,0x00,0x00,0x00,0x00,0x0E,0x00,0x0F,0x80,0x00,0x00,
0x00,0x00,0x01,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xC0,0x00,0x00,
0x00,0x00,0x01,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xC0,0x00,0x00,
0x00,0x00,0x03,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xE0,0x00,0x00,
0x00,0x00,0x01,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xC0,0x00,0x00,
0x00,0x00,0x07,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xF0,0x00,0x00,
0x00,0x00,0x07,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xF0,0x00,0x00,
0x00,0x00,0x0F,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xF8,0x00,0x00,
0x00,0x00,0x0F,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xF8,0x00,0x00,
0x00,0x00,0x0F,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xF8,0x00,0x00,
0x00,0x00,0x1F,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xFC,0x00,0x00,
0x00,0x00,0x0F,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0xFC,0x00,0x00,
0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xFC,0x00,0x00,
0x00,0x00,0x0F,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xF0,0x00,0x00,
0x00,0x00,0x07,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF8,0x00,0x00,
0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xB0,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00

};

INT8U graphic_D4[2048]=	   // 
{
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x0C,0x67,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1E,0xCF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x11,0xCF,0xBC,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x7B,0xCF,0xFC,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x7F,0x8F,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x07,0xFF,0xCF,0xE7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x1F,0xFF,0xE5,0xFF,0xD8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x7C,0xFF,0xFA,0xFF,0xEC,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x01,0xF8,0xFF,0xFD,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x03,0xFD,0xFF,0xFC,0xFF,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x1F,0xFF,0xFF,0xFE,0x7E,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x7F,0xFF,0xFF,0xFF,0x7F,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xEF,0xFF,0xFF,0xFF,0xBF,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xE7,0xFF,0xFF,0xFF,0xBF,0xC7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x67,0xFF,0xFF,0xFF,0x5F,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xDF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xF7,0xFF,0xFF,0xFF,0xC7,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x03,0xFF,0xFF,0xFF,0xCF,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x07,0xFF,0xFD,0xFF,0xEF,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x07,0xE3,0xD1,0xFF,0xEF,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x3F,0x80,0xE7,0xFF,0xEF,0xF9,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x1E,0x00,0x17,0xFF,0xEF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xDF,0xFF,0xEF,0xC4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x01,0xFF,0xFF,0xEF,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x03,0xFF,0xFF,0xEF,0xFB,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x07,0xFF,0xFF,0xEF,0xFF,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x0F,0xFF,0xFF,0xEF,0xD8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x1F,0xFF,0xFF,0xCF,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x1F,0xFF,0xFF,0xC7,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x3F,0xFF,0xFF,0xDF,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x7F,0xFF,0xFF,0xDF,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x18,
0x00,0x07,0x80,0x00,0x7F,0xFF,0xFF,0x9F,0xFA,0x00,0x00,0x00,0x00,0x00,0x00,0x0C,
0x00,0x0F,0xC0,0x00,0xFF,0xFF,0xFF,0x9F,0xFA,0x00,0x00,0x00,0x00,0x00,0x00,0x7C,
0x00,0x1F,0xC0,0x01,0xFF,0xFF,0xFF,0x1F,0x00,0x00,0x00,0x00,0x00,0x1F,0x80,0x7C,
0x00,0x1F,0xE0,0x01,0xFF,0xFF,0xFF,0xBF,0xE0,0x00,0x00,0x00,0x04,0x7F,0xF0,0x60,
0x00,0x3F,0xF0,0x03,0xFF,0xFF,0xFF,0x1E,0xD8,0x00,0x00,0x00,0x0E,0xFF,0xFA,0x60,
0x00,0x7F,0xF8,0x07,0xFF,0xFF,0xFF,0x3C,0x98,0x00,0x00,0x00,0x06,0x7F,0xDF,0xF0,
0x00,0xFB,0xF8,0x0F,0xFF,0xFF,0xFF,0x3F,0x00,0x00,0x00,0x00,0x0D,0xFF,0xFF,0xE0,
0x01,0xF1,0xFC,0x1F,0xFF,0xFF,0xFF,0x7B,0x00,0x00,0x00,0x00,0x0D,0xFF,0xFD,0xB0,
0x03,0xE0,0xFF,0x1F,0xFF,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x00,0x3B,0xFF,0xC0,0x00,
0x07,0xE0,0x7F,0xBF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x3F,0xFF,0xF0,0x00,
0x0F,0xC0,0x3F,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x00,0x7F,0xFF,0xFF,0x80,
0x0F,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x7F,0xFF,0xFF,0xE0,
0x1F,0x80,0x1F,0xFF,0xFF,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x00,0x7F,0xFF,0xFF,0x70,
0x1F,0x80,0x0F,0xBF,0xFF,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x00,0x7F,0xFF,0xF0,0x00,
0x1F,0xE0,0x0F,0x3F,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,0x3F,0xFF,0xFC,0x00,
0x1F,0xE0,0x0F,0x7F,0xFF,0xFF,0xFF,0xFF,0x80,0x00,0x00,0x00,0x3F,0xFF,0xFD,0x80,
0x1F,0xC0,0x0F,0x7F,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,0x00,0x00,0x3F,0xFF,0xFD,0x80,
0x1F,0x80,0x07,0x3F,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x1F,0xFF,0xFC,0x00,
0x1F,0x03,0xC1,0x3F,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x1F,0xFF,0xF0,0x00,
0x3C,0x03,0xF8,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x00,0x00,0x1F,0xFF,0xF9,0x00,
0x7F,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x0F,0xFF,0xFF,0x00,
0x7F,0x87,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x00,0x00,0x0F,0xFF,0xFC,0x00,
0x3F,0x87,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x0F,0xFB,0xC0,0x00,
0x7F,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0x00,0x0F,0xF0,0x00,0x00,
0x78,0x03,0xCF,0xFF,0xFB,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x00,0x0F,0xE0,0x00,0x00,
0x00,0x03,0xC1,0xFF,0xFB,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x0F,0xEF,0x80,0x00,
0x00,0x03,0xC0,0x7F,0xFB,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x80,0x0F,0xFF,0xF0,0x00,
0x00,0x03,0xC0,0x3F,0xFB,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE0,0x0F,0xFF,0x80,0x00,
0x00,0x01,0xC0,0x0F,0xF9,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x1F,0xFE,0x00,0x00,
0x00,0x01,0xC0,0x07,0xF7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,
0x00,0x01,0xF8,0x01,0xF7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC0,0x00,
0x00,0x01,0xFE,0x00,0x07,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFB,0xC0,0x00,
0x00,0x01,0xFE,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,
0x00,0x01,0xFC,0x00,0x00,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,
0x00,0x01,0xFC,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x5F,0x00,0x00,
0x00,0x01,0xFE,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x3F,0xC0,0x00,0x00,
0x00,0x00,0xFE,0x00,0x00,0x02,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x1F,0xE0,0x00,0x00,
0x00,0x00,0x7F,0x60,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x0F,0xF0,0x00,0x00,
0x00,0x00,0x1E,0xC0,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0x06,0x70,0x00,0x00,
0x00,0x00,0x06,0xC0,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,
0x00,0x00,0x0F,0xE0,0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,
0x00,0x00,0x0F,0xE0,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xFE,0x00,0x00,0x00,0x00,
0x00,0x00,0x07,0xE0,0x00,0x00,0x00,0x00,0x03,0xFF,0xFF,0xFE,0x00,0x00,0x00,0x00,
0x00,0x00,0x01,0xC0,0x00,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFE,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x03,0xF9,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xFD,0xFF,0xFF,0xFC,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xFD,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xF9,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFE,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xFF,0xFF,0xF8,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xFD,0xFF,0xFC,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xFC,0xFF,0xFC,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xFC,0x3F,0xFE,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xFC,0x0F,0xFF,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xFC,0x03,0xFF,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xF8,0x03,0xFF,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xF0,0x01,0xFF,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xE0,0x00,0xFF,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x80,0x00,0x7F,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0x00,0x00,0x3E,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3C,0x00,0x00,0x78,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3C,0x00,0x00,0x7C,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF8,0x00,0x00,0x78,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF0,0x00,0x00,0xF8,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xF8,0x00,0x00,0x70,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xF8,0x00,0x01,0xF0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xF8,0x00,0x03,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0xC0,0x00,0x01,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x07,0xF0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xFE,0x00,0x00,0x0F,0xF0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xB8,0x00,0x00,0x1F,0xF8,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xF6,0x00,0x00,0x3F,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x02,0xFC,0x00,0x00,0x1F,0x80,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xFC,0x00,0x01,0xFF,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xF8,0x00,0x03,0xFE,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xE0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xEC,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xFC,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xF8,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x70,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
};

INT8U graphic_D5[2048]=	   // 
{
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x1F,0xFF,0xFF,0xFE,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x37,0xFF,0xFF,0xFF,0xFF,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x07,0x83,0xE3,0xFF,0xFF,0xFF,0xC0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x07,0xFF,0xFF,0xFC,0x1F,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x0F,0xFF,0xFF,0xF8,0x00,0x00,0x3F,0xC0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x07,0x80,0x7F,0xFB,0xFF,0x83,0xFF,0xFE,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x03,0x03,0x7F,0xFB,0xFF,0xF8,0xFF,0xFF,0xC0,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xF2,0x3F,0xFE,0x7F,0xFF,0xF8,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x01,0xFF,0xE0,0x00,0xFF,0x3E,0x00,0x3C,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x3F,0xFF,0xF8,0x00,0x1F,0xBE,0x00,0x07,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x7F,0xFF,0xFE,0x00,0x0F,0xBF,0xC0,0x01,0x80,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1F,0xFE,0x7F,0x00,0x0F,0xBF,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1B,0xFE,0x01,0xC0,0x1F,0x3F,0xF8,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x01,0x8F,0x00,0x60,0x3F,0x70,0xFC,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xC3,0x80,0x00,0x7E,0x7C,0x1E,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x01,0xFC,0xFE,0x07,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xF8,0x0F,0x03,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0xE0,0x01,0x81,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xFF,0xC0,0x00,0x80,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC0,0x00,0x00,0x0F,0xFF,0x00,0x00,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x70,0xE1,0x80,0x00,0x03,0xFE,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x1C,0x79,0xC3,0x80,0x07,0xF8,0xC7,0xE0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x1F,0xFF,0xE3,0xF0,0x3F,0xE3,0x9F,0xFE,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x1F,0xFF,0xFF,0xF9,0xFC,0xFF,0x8F,0x3F,0xF1,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x03,0xFE,0x03,0xFD,0xF9,0xFF,0x3F,0x3F,0xFC,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x03,0xE3,0xFC,0x7F,0xF3,0xFE,0x7E,0x7F,0xFF,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x7F,0xDF,0xFF,0x9F,0xE7,0xF8,0xFE,0x7F,0xFF,0xC0,0x00,0x00,0x00,0x00,
0x00,0x03,0xFF,0x37,0xFF,0xE7,0xCF,0xF1,0xFE,0x01,0xFF,0xF0,0x00,0x00,0x00,0x00,
0x00,0x00,0x3E,0xC1,0xFF,0xF3,0x9F,0xE3,0xFC,0x01,0x3F,0xB8,0x00,0x00,0x00,0x00,
0x00,0x00,0x7F,0xC0,0xF3,0xF9,0xBF,0xE7,0xCC,0x01,0xCF,0x84,0x00,0x00,0x00,0x00,
0x00,0x01,0xD9,0x80,0x79,0xF1,0x3F,0xCF,0xC4,0x00,0x73,0xC2,0x00,0x00,0x00,0x00,
0x00,0x03,0x31,0x00,0x38,0xF0,0x3F,0xDF,0xC0,0x00,0x3C,0xE0,0x00,0x00,0x00,0x00,
0x00,0x0C,0x61,0x00,0x1C,0x78,0x7F,0x9F,0xC0,0x00,0xFF,0x72,0x00,0x00,0x00,0x00,
0x00,0x00,0x40,0x00,0x1C,0x38,0x0F,0x9F,0xC0,0x00,0xFF,0x9B,0x80,0x00,0x00,0x00,
0x00,0x00,0x80,0x00,0x0C,0x1C,0x0F,0xBF,0xC0,0x00,0x1F,0xC9,0xC0,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x0C,0x0C,0x0F,0x3F,0xC0,0x00,0x3F,0x05,0xF0,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x04,0x06,0x0F,0x3F,0xE0,0x00,0x27,0x00,0xF8,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x04,0x06,0x0F,0x3F,0xE0,0x00,0x03,0x78,0xE4,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x02,0x07,0x3F,0xF0,0x00,0x01,0x7C,0xF0,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x03,0x07,0xBF,0xF8,0x00,0x01,0xBF,0xF8,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x01,0x07,0xBF,0xFC,0x00,0x00,0x83,0xE8,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x9F,0xFE,0x00,0x00,0x01,0xE0,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x9F,0xFF,0x80,0x00,0x00,0xE0,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x01,0x01,0xCF,0xEF,0xE0,0x00,0x00,0x20,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCF,0xE0,0x78,0x00,0x00,0x30,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x67,0xF8,0x00,0x00,0x00,0x10,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x37,0xFC,0x00,0x00,0x00,0x10,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xFE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xFF,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0xFE,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x9F,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC7,0xFF,0xFF,0xC0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE0,0xFF,0xF8,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF8,0x3F,0xE0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFC,0x07,0xF0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0xF8,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xCC,0x7C,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xE3,0x1E,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xDF,0xF9,0x8E,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCF,0xFC,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x87,0xFF,0x31,0x83,0xFF,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x87,0xFF,0x99,0x9F,0xFF,0xC0,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x27,0x9F,0xDC,0x9F,0xFC,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0x9F,0xCE,0x5F,0xFF,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF3,0x9F,0xE7,0x1F,0xFF,0xC0,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xF3,0x9F,0xF3,0x9F,0xFF,0xF0,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xF3,0x8F,0x33,0x80,0xFE,0x38,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0xF7,0x0F,0x19,0xC0,0x1F,0x8C,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xFF,0xE7,0x0E,0x19,0xEF,0x87,0xC6,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x03,0xFF,0xFF,0xE7,0x0E,0x0D,0xE7,0xF1,0xE3,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xE6,0x0E,0x04,0xF7,0xF8,0xF1,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0xEE,0x0E,0x04,0xF3,0xFE,0x38,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0xCC,0x0E,0x00,0xF3,0xFF,0x1C,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0xC8,0x0C,0x00,0xF1,0xE1,0x8E,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xF3,0x90,0x0C,0x00,0xF8,0x70,0x06,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xE7,0x00,0x0C,0x00,0xF8,0x30,0x03,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x86,0x00,0x08,0x00,0xF8,0x18,0x03,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x3E,0x0C,0x00,0x08,0x00,0xF8,0x08,0x01,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xF8,0x18,0x00,0x00,0x00,0xF0,0x08,0x00,0x80,0x00,
0x00,0x00,0x00,0x00,0x00,0x03,0xC0,0x20,0x00,0x00,0x00,0xF0,0x08,0x00,0x80,0x00,
0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x05,0xF0,0x04,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1B,0xC0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x17,0x80,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x27,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4E,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x9C,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x38,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0E,0x70,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x39,0xC0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0xF3,0x80,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE3,0xCE,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x8E,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0xFC,0x38,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xF1,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xE7,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x8E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0x3C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x3E,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x7E,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xCC,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x8C,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x08,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x08,0xE0,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x08,0xF0,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x70,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x78,0x80,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x3C,0x80,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x1C,0xC0,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x0F,0xE2,0x70,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xF2,0x30,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xFB,0x38,0x30,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xFF,0x1C,0x10,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0x9E,0x18,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0xCF,0x1E,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xCF,0x8F,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xE7,0xCF,0x80,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xE7,0xFF,0xE0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x73,0xFF,0xF8,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5F,0xF3,0xFF,0xFE,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0xF9,0xFF,0xFF,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xF9,0xFF,0xFF,0xF0,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xBF,0xFF,0xFC,0x00,0x00,0x00
};	  
